@@ -1,5 +1,3 @@
-use std::convert::TryFrom;
-
 use jsonpath_lib::Compiled;
 use serde_json::{from_slice as deserialize, Value};
 use wiremock::{Match, Request};
@@ -24,7 +22,7 @@ impl TryFrom<&BodyPatternStub> for JsonPathMatcher {
         body.matches_json_path.as_ref()
             .filter(|_| body.is_by_json_path())
             .and_then(|it| jsonpath_lib::Compiled::compile(it.as_str()).ok())
-            .map(JsonPathMatcher)
-            .ok_or_else(|| anyhow::Error::msg("No json path matcher found"))
+            .map(Self)
+            .ok_or_else(|| anyhow::Error::msg(""))
     }
 }
\ No newline at end of file
