@@ -1,5 +1,3 @@
-use std::convert::TryFrom;
-
 use jsonpath_lib::select as matches_json_path;
 use serde_json::{from_slice as deserialize, Value};
 use wiremock::{Match, Request};
@@ -25,11 +23,10 @@ impl TryFrom<&BodyPatternStub> for JsonPathContainsMatcher {
     type Error = anyhow::Error;
 
     fn try_from(body: &BodyPatternStub) -> anyhow::Result<Self> {
-        if body.is_by_json_path_contains() {
-            body.expression.as_ref()
-                .and_then(|path| body.contains.as_ref().map(|contains| (path, contains)))
-                .map(|(path, contains)| JsonPathContainsMatcher(path.to_string(), contains.to_owned()))
-                .ok_or_else(|| anyhow::Error::msg("No json path with contains matcher found"))
-        } else { anyhow::Result::Err(anyhow::Error::msg("No json path with contains matcher found")) }
+        body.expression.as_ref()
+            .filter(|_| body.is_by_json_path_contains())
+            .and_then(|path| body.contains.as_ref().map(|contains| (path, contains)))
+            .map(|(path, contains)| Self(path.to_string(), contains.to_owned()))
+            .ok_or_else(|| anyhow::Error::msg(""))
     }
 }
\ No newline at end of file
