@@ -1,5 +1,3 @@
-use std::convert::TryFrom;
-
 use jsonpath_lib::select as matches_json_path;
 use serde_json::{from_slice as deserialize, Value};
 use wiremock::{Match, Request};
@@ -22,11 +20,10 @@ impl TryFrom<&BodyPatternStub> for JsonPathEqMatcher {
     type Error = anyhow::Error;
 
     fn try_from(body: &BodyPatternStub) -> anyhow::Result<Self> {
-        if body.is_by_json_path_eq() {
-            body.expression.as_ref()
-                .and_then(|path| body.equal_to_json.as_ref().map(|eq| (path, eq)))
-                .map(|(path, eq)| JsonPathEqMatcher(path.to_string(), eq.to_owned()))
-                .ok_or_else(|| anyhow::Error::msg("No json path with eq matcher found"))
-        } else { anyhow::Result::Err(anyhow::Error::msg("No json path with eq matcher found")) }
+        body.expression.as_ref()
+            .filter(|_| body.is_by_json_path_eq())
+            .and_then(|path| body.equal_to_json.as_ref().map(|eq| (path, eq)))
+            .map(|(path, eq)| Self(path.to_string(), eq.to_owned()))
+            .ok_or_else(|| anyhow::Error::msg(""))
     }
 }
\ No newline at end of file
