@@ -1,16 +1,20 @@
-use std::convert::TryFrom;
-
 use itertools::Itertools;
 use wiremock::matchers::{header, HeaderExactMatcher};
 
 use super::{HttpReqHeadersStub, super::matcher::RequestMatcherStub};
 
-impl From<&HttpReqHeadersStub> for Vec<HeaderExactMatcher> {
-    fn from(headers: &HttpReqHeadersStub) -> Self {
-        headers.get_headers().iter()
-            .filter(|h| h.is_exact_match())
-            .map(HeaderExactMatcher::try_from).flatten()
-            .collect_vec()
+impl TryFrom<&HttpReqHeadersStub> for Vec<HeaderExactMatcher> {
+    type Error = anyhow::Error;
+
+    fn try_from(headers: &HttpReqHeadersStub) -> anyhow::Result<Self> {
+        headers.get_headers()
+            .ok_or_else(|| anyhow::Error::msg(""))
+            .map(|iter| {
+                iter
+                    .filter(|h| h.is_exact_match())
+                    .filter_map(|it| HeaderExactMatcher::try_from(&it).ok())
+                    .collect_vec()
+            })
     }
 }
 
