@@ -3,7 +3,6 @@ use std::{
     fs::OpenOptions,
     i64,
     io::Read,
-    iter::FromIterator,
     path::PathBuf,
     str::{from_utf8, FromStr},
 };
@@ -30,6 +29,9 @@ pub struct BodyStub {
     /// json body
     #[serde(skip_serializing_if = "Option::is_none")]
     pub json_body: Option<Value>,
+    /// binary Base 64 encoded body
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub base_64_body: Option<String>,
     /// relative path to raw body content
     #[serde(default, skip_serializing, deserialize_with = "deserialize_body_file")]
     pub body_file_name: Option<BodyFile>,
@@ -46,7 +48,7 @@ impl BodyStub {
     fn register_json_body_template<'a, T>(&self, json_values: T) where T: Iterator<Item=&'a JsonValue> {
         json_values.into_iter().for_each(|value| {
             match value {
-                Value::String(s) => self.register(&s, s),
+                Value::String(s) => self.register(s, s),
                 Value::Object(o) => self.register_json_body_template(o.values()),
                 Value::Array(a) => self.register_json_body_template(a.iter()),
                 _ => {}
@@ -63,19 +65,19 @@ impl BodyStub {
     fn render_json_obj(&self, json_body: &Map<String, Value>, data: &HandlebarsData) -> Value {
         let obj = json_body.into_iter()
             .map(|(key, value)| match value {
-                Value::String(s) => (key.to_owned(), Self::cast_to_value(self.render(&s, data))),
-                Value::Object(o) => (key.to_owned(), self.render_json_obj(&o, data)),
-                Value::Array(a) => (key.to_owned(), self.render_json_array(&a, data)),
+                Value::String(s) => (key.to_owned(), Self::cast_to_value(self.render(s, data))),
+                Value::Object(o) => (key.to_owned(), self.render_json_obj(o, data)),
+                Value::Array(a) => (key.to_owned(), self.render_json_array(a, data)),
                 _ => (key.to_owned(), value.to_owned())
             });
         Value::from(Map::from_iter(obj))
     }
 
-    fn render_json_array(&self, json_body: &Vec<Value>, data: &HandlebarsData) -> Value {
-        Value::Array(json_body.into_iter().map(|value| match value {
-            Value::String(s) => Self::cast_to_value(self.render(&s, data)),
-            Value::Object(o) => self.render_json_obj(&o, data),
-            Value::Array(a) => self.render_json_array(&a, data),
+    fn render_json_array(&self, json_body: &[Value], data: &HandlebarsData) -> Value {
+        Value::Array(json_body.iter().map(|value| match value {
+            Value::String(s) => Self::cast_to_value(self.render(s, data)),
+            Value::Object(o) => self.render_json_obj(o, data),
+            Value::Array(a) => self.render_json_array(a, data),
             _ => value.to_owned()
         }).collect_vec())
     }
@@ -110,6 +112,11 @@ impl BodyStub {
             _ => Value::from(raw)
         }
     }
+
+    fn binary_body(&self) -> Option<Vec<u8>> {
+        self.base_64_body.as_ref()
+            .and_then(|b| base64::decode(b).ok())
+    }
 }
 
 fn deserialize_body_file<'de, D>(path: D) -> Result<Option<BodyFile>, D::Error> where D: Deserializer<'de> {
@@ -142,13 +149,15 @@ impl HandlebarTemplatable for BodyStub {
                 self.register_json_body_template(array.iter());
             }
         } else if let Some(body_file) = self.body_file_name.as_ref() {
-            self.register(body_file.path.as_str(), body_file.content.clone());
+            self.register(body_file.path.as_str(), &body_file.content);
         }
     }
 
     fn render_response_template(&self, mut template: ResponseTemplate, data: &HandlebarsData) -> ResponseTemplate {
         if let Some(body) = self.body.as_ref() {
-            template = template.set_body_string(self.render(&body, data));
+            template = template.set_body_string(self.render(body, data));
+        } else if let Some(binary) = self.binary_body() {
+            template = template.set_body_bytes(binary);
         } else if let Some(json_body) = self.render_json_body(self.json_body.as_ref(), data) {
             template = template.set_body_json(json_body);
         } else if let Some(body_file) = self.body_file_name.as_ref() {
@@ -161,9 +170,10 @@ impl HandlebarTemplatable for BodyStub {
 
 impl ResponseAppender for BodyStub {
     fn add(&self, mut resp: ResponseTemplate) -> ResponseTemplate {
-        if let Some(text) = self.body.as_ref() { resp = resp.set_body_string(text) }
         if let Some(json) = self.json_body.as_ref() { resp = resp.set_body_json(json) }
-        if let Some(body_file) = self.body_file_name.as_ref() { resp = body_file.add(resp) }
+        else if let Some(text) = self.body.as_ref() { resp = resp.set_body_string(text) }
+        else if let Some(body_file) = self.body_file_name.as_ref() { resp = body_file.add(resp) }
+        else if let Some(binary) = self.binary_body() { resp = resp.set_body_bytes(binary) }
         resp
     }
 }
\ No newline at end of file
